# langchain_opensearch

This repository contains 1 package with OpenSearch integrations with LangChain:

langchain-opensearch integrates Opensearch 

---

TODO 
1. OpensearchStore 구현
2. OpensearchRetriever 구현
3. 그외 langchain-elastic에서 제공하는 여러 기능 구현.

---
License
This project is developed by referencing the [langchain-elastic package](https://github.com/langchain-ai/langchain-elastic), which is licensed under the MIT License.
This project is also licensed under the MIT License - see the LICENSE file for details.

This project is licensed under the MIT License - see the [LICENSE](./LICENSE) file for details.
